% export_results_d1 - Export foveal center location results
%
% This script merges the results related to the foveal center location 
% method comparison:
% 1- Calculate alignment dissimilarity
% 2- Merge all results in a single table
%
% 2021, Mondragon Unibertsitatea, Biomedical Engineering Department
% -------------------------------------------------------------------------

close all;clc;clearvars;

addpath(genpath('../utils'));

inputPath = '../../data/derivatives/2_thickness';

% Load subjects list 
opts = detectImportOptions('../../data/raw/subjects.tsv','FileType','text');
subjects = readtable('../../data/raw/subjects.tsv',opts);

% Choose one eye per subject
eyes = chooseEyes(subjects);

nSubject = size(subjects,1);

interpMethod = 'cubic'; % linearInterp
alignMethodList = {'none','min','resample_min','smooth_min'};
Grid.type = 'regular';
Grid.maxD = 1.5;
Grid.step = 0.02;
Grid.nAngles = 0;
 

nAlignMethod = length(alignMethodList);

for i = 1:nAlignMethod
    
    alignMethod = alignMethodList{i};
    
    % Create folder of each combo
    comboPath = [inputPath '/' alignMethod '_' Grid.type '_' num2str(Grid.maxD) '_' num2str(Grid.step) '_' num2str(Grid.nAngles)];
    
    for iSubject = 1:nSubject
        
        % Get subjectId
        subject = subjects.subject{iSubject};
        eye = eyes{iSubject};        
        eyePath = [subject '/' eye ];
                
        % Load raster thickness
        scanType = 'raster';
        fileName = [subject '_' eye '_' scanType '_thickness.mat'];
        
        load([comboPath '/' eyePath '/' fileName],'TRT');
        
        rasterTRT.(alignMethod)(iSubject) = {TRT};    
        
        % Get star thickness
        scanType = 'star';
        fileName = [subject '_' eye '_' scanType '_thickness.mat'];
                                
        load([comboPath '/' eyePath '/' fileName],'TRT');
        
        starTRT.(alignMethod)(iSubject) = {TRT};
    end
end

T = table;
T.subject = subjects.subject;

for i = 1:nAlignMethod
    alignMethod = alignMethodList{i};
         
    % Alignment dissimilarity (raster vs star of the same eye)
    T.(alignMethod) = 1e3*cell2mat(cellfun(@(x,y) nanmean(abs(x(:)-y(:))),...
        rasterTRT.(alignMethod),starTRT.(alignMethod),'UniformOutput',false))';       
end

writetable(T,'../data_analysis/results_1.csv');