function [lb,ub] = getCI(x,th,method,N)
% getCI - Compute confidence interval
%
% [lb,ub] = getCI(x,th,method,N)
%
% Input arguments:
%   x: data distribution
%   th: % threshold of the CI
%   method: CI calculation method
%   N: number of resamplings for Bootstrap
%
% Output arguments:
%   lb: lower bound of the CI
%   ub: upper bound of the CI
%
% Normal method calculation based on the answer in :
% https://es.mathworks.com/matlabcentral/answers/159417-how-to-calculate-the-confidence-interval
%
%  2021, Mondragon Unibertsitatea, Biomedical Engineering Department


nSamp = length(x);
switch method
    case 'normal'
        
        varX = std(x(:),'omitnan');
        muX = mean(x(:),'omitnan');
        
        t = tinv(abs([0,1]-(1-th/100)/2),sum(~isnan(x(:)))-1);
        ci = varX/sqrt(sum(~isnan(x(:))))*t + muX;
        lb = ci(1);
        ub = ci(2);
    case 'prctile'
        error('not supported yet');
    case 'bootstrap'
        mu = nan(1,N);
        for n=1:N
            y = datasample(x,nSamp,'Replace',true);
            mu(n) = mean(y);
        end
        
        lb = prctile(mu,(100-th)/2);
        ub = prctile(mu,100-(100-th)/2);
    otherwise
        error('not supported CI method');
end