function Paramorf = getMorphParams(rho,TRT)
% getMorphParams - compute morphological parameters of the foveal pit
% based on TRT values
%
% Paramorf = getMorphParams(rho,TRT)
%
% Input arguments:
%   rho: matrix with rho coordinates
%   TRT: matrix with TRT points (each row is an angular direction)
%
% Output arguments:
%   Paramorf: struct with morphological parameters
%
%  2021, Mondragon Unibertsitatea, Biomedical Engineering Department

% Get step
nAngles = size(TRT, 1);

step = rho(1,2)-rho(1,1);

% Check both axis in mm
if step>1 | max(TRT(1))>1
    error('Wrong units');
end

% Radial parameter computation
for n=1:nAngles

    x = rho(n,:);
    y = TRT(n,:);

    % Central Foveal Thickness
    Paramorf.CFT(n) = 1e3*y(1);

    % Rim height 
    [Paramorf.rimHeight(n),indMax] = max(1e3*y);
    indMax = indMax(1); % por si > 1 mnimo

    % Rim Radius
    Paramorf.rimRadius(n) = x(indMax);

    % Max Slope
    if indMax>1
        yDiff = diff(y(1:indMax))./step;
        [maxSlope,~] = max(yDiff);
        maxSlope = maxSlope(1);
    else
        yDiff = diff(y)./step;
        [maxSlope,~] = max(yDiff);
        maxSlope = maxSlope(1);
     
    end
    Paramorf.maxSlope(n) = 180*atan(maxSlope)/pi;


end