function [TRT_fit,fitparams] = movingAverage(TRT,nMoving)
% movingAverage - smooth the TRT curves by a moving average smoother
%
% [TRT_fit,fitparams] = movingAverage(TRT,nMoving)
%
% Input arguments:
%   TRT: matrix with TRT points (each row is an angular direction)
%   nMoving: number of averaged samples
%
% Output arguments:
%   TRT_fit: fitted TRT values
%   fitparams: equal to nMoving
%
%  2021, Mondragon Unibertsitatea, Biomedical Engineering Department


[nAngles, nPoints] = size(TRT);

nBScans = nAngles/2;

TRT_fit = nan(nAngles,nPoints);

for n=1:nBScans

    % Reconstruct the B-Scan
    y = [fliplr(TRT(n+nBScans, :)) TRT(n, 2:end)]; % Dont get center two times

    % Smooth the signal    
    ySmooth = movmean(y,nMoving);

    % From fitted B-Scan to radial again   
    TRT_fit(n,:) = ySmooth((end-nPoints+1):end);% Right part of the B-Scan
    TRT_fit(n+nBScans,:) = ySmooth(nPoints:-1:1);
end

fitparams = nMoving;
